/* anti-linking.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from anti-linking.vala, do not modify */

/*
 * Copyright (C) 2012 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *          Travis Reitter <travis.reitter@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gee.h>
#include <gio/gio.h>


#define TYPE_ANTI_LINKING_TESTS (anti_linking_tests_get_type ())
#define ANTI_LINKING_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ANTI_LINKING_TESTS, AntiLinkingTests))
#define ANTI_LINKING_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ANTI_LINKING_TESTS, AntiLinkingTestsClass))
#define IS_ANTI_LINKING_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ANTI_LINKING_TESTS))
#define IS_ANTI_LINKING_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ANTI_LINKING_TESTS))
#define ANTI_LINKING_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ANTI_LINKING_TESTS, AntiLinkingTestsClass))

typedef struct _AntiLinkingTests AntiLinkingTests;
typedef struct _AntiLinkingTestsClass AntiLinkingTestsClass;
typedef struct _AntiLinkingTestsPrivate AntiLinkingTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _AntiLinkingTestsTestAntiLinkingBasicAsyncData AntiLinkingTestsTestAntiLinkingBasicAsyncData;
typedef struct _AntiLinkingTestsTestAntiLinkingRemovalAsyncData AntiLinkingTestsTestAntiLinkingRemovalAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _AntiLinkingTests {
	EdsTestTestCase parent_instance;
	AntiLinkingTestsPrivate * priv;
};

struct _AntiLinkingTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _AntiLinkingTestsPrivate {
	FolksIndividualAggregator* _aggregator;
	GMainLoop* _main_loop;
	gboolean _found_before_update;
	gboolean _found_after_update;
	gboolean _found_after_final_update;
};

struct _AntiLinkingTestsTestAntiLinkingBasicAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	AntiLinkingTests* self;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* store;
	FolksBackendStore* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e;
	GError* _tmp5_;
	const gchar* _tmp6_;
	GError * _inner_error_;
};

struct _AntiLinkingTestsTestAntiLinkingRemovalAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	AntiLinkingTests* self;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* store;
	FolksBackendStore* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e;
	GError* _tmp5_;
	const gchar* _tmp6_;
	GError * _inner_error_;
};


static gpointer anti_linking_tests_parent_class = NULL;

GType anti_linking_tests_get_type (void) G_GNUC_CONST;
#define ANTI_LINKING_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_ANTI_LINKING_TESTS, AntiLinkingTestsPrivate))
enum  {
	ANTI_LINKING_TESTS_DUMMY_PROPERTY
};
#define ANTI_LINKING_TESTS__full_name_1 "bernie h. innocenti"
#define ANTI_LINKING_TESTS__email_1 "bernie@example.org"
#define ANTI_LINKING_TESTS__full_name_2 "Clyde McPoyle"
AntiLinkingTests* anti_linking_tests_new (void);
AntiLinkingTests* anti_linking_tests_construct (GType object_type);
static void anti_linking_tests_test_anti_linking_basic (AntiLinkingTests* self);
static void _anti_linking_tests_test_anti_linking_basic_folks_test_case_test_method (gpointer self);
static void anti_linking_tests_test_anti_linking_removal (AntiLinkingTests* self);
static void _anti_linking_tests_test_anti_linking_removal_folks_test_case_test_method (gpointer self);
static void anti_linking_tests_real_set_up (FolksTestCase* base);
static void anti_linking_tests_real_tear_down (FolksTestCase* base);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _anti_linking_tests_test_anti_linking_basic_async (AntiLinkingTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _anti_linking_tests_test_anti_linking_basic_finish (AntiLinkingTests* self, GAsyncResult* _res_);
static void _anti_linking_tests_test_anti_linking_basic_async_data_free (gpointer _data);
static gboolean _anti_linking_tests_test_anti_linking_basic_async_co (AntiLinkingTestsTestAntiLinkingBasicAsyncData* _data_);
static void _anti_linking_tests_test_anti_linking_basic_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _anti_linking_tests_individuals_changed_aggregate_after_change_cb (AntiLinkingTests* self, GeeMultiMap* changes);
static void __anti_linking_tests_individuals_changed_aggregate_after_change_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _anti_linking_tests_test_anti_linking_removal_async (AntiLinkingTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _anti_linking_tests_test_anti_linking_removal_finish (AntiLinkingTests* self, GAsyncResult* _res_);
static void _anti_linking_tests_test_anti_linking_removal_async_data_free (gpointer _data);
static gboolean _anti_linking_tests_test_anti_linking_removal_async_co (AntiLinkingTestsTestAntiLinkingRemovalAsyncData* _data_);
static void _anti_linking_tests_test_anti_linking_removal_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _anti_linking_tests_individuals_changed_anti_linking_removal_cb (AntiLinkingTests* self, GeeMultiMap* changes);
static void __anti_linking_tests_individuals_changed_anti_linking_removal_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void anti_linking_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _anti_linking_tests_test_anti_linking_basic_folks_test_case_test_method (gpointer self) {
#line 42 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	anti_linking_tests_test_anti_linking_basic ((AntiLinkingTests*) self);
#line 149 "anti-linking.c"
}


static void _anti_linking_tests_test_anti_linking_removal_folks_test_case_test_method (gpointer self) {
#line 43 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	anti_linking_tests_test_anti_linking_removal ((AntiLinkingTests*) self);
#line 156 "anti-linking.c"
}


AntiLinkingTests* anti_linking_tests_construct (GType object_type) {
	AntiLinkingTests * self = NULL;
#line 40 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	self = (AntiLinkingTests*) eds_test_test_case_construct (object_type, "AntiLinking");
#line 42 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "basic anti-linking", _anti_linking_tests_test_anti_linking_basic_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 43 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "anti-link removal", _anti_linking_tests_test_anti_linking_removal_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 38 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	return self;
#line 170 "anti-linking.c"
}


AntiLinkingTests* anti_linking_tests_new (void) {
#line 38 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	return anti_linking_tests_construct (TYPE_ANTI_LINKING_TESTS);
#line 177 "anti-linking.c"
}


static void anti_linking_tests_real_set_up (FolksTestCase* base) {
	AntiLinkingTests * self;
#line 46 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	self = (AntiLinkingTests*) base;
#line 48 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	FOLKS_TEST_CASE_CLASS (anti_linking_tests_parent_class)->set_up ((FolksTestCase*) G_TYPE_CHECK_INSTANCE_CAST (self, EDS_TEST_TYPE_TEST_CASE, EdsTestTestCase));
#line 50 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	self->priv->_found_before_update = FALSE;
#line 51 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	self->priv->_found_after_update = FALSE;
#line 52 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	self->priv->_found_after_final_update = FALSE;
#line 193 "anti-linking.c"
}


static void anti_linking_tests_real_tear_down (FolksTestCase* base) {
	AntiLinkingTests * self;
#line 55 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	self = (AntiLinkingTests*) base;
#line 58 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 58 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	self->priv->_aggregator = NULL;
#line 60 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	FOLKS_TEST_CASE_CLASS (anti_linking_tests_parent_class)->tear_down ((FolksTestCase*) G_TYPE_CHECK_INSTANCE_CAST (self, EDS_TEST_TYPE_TEST_CASE, EdsTestTestCase));
#line 207 "anti-linking.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 78 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 214 "anti-linking.c"
}


static void _vala_GValue_free (GValue* self) {
#line 78 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_value_unset (self);
#line 78 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_free (self);
#line 223 "anti-linking.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 79 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	return self ? _g_value_dup (self) : NULL;
#line 230 "anti-linking.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 85 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	return self ? g_object_ref (self) : NULL;
#line 237 "anti-linking.c"
}


static void anti_linking_tests_test_anti_linking_basic (AntiLinkingTests* self) {
	GeeHashMap* c = NULL;
	GMainLoop* _tmp0_ = NULL;
	GValue* v = NULL;
	GeeHashMap* _tmp1_ = NULL;
	GValue _tmp2_ = {0};
	GValue _tmp3_ = {0};
	GValue* _tmp4_ = NULL;
	GValue* _tmp5_ = NULL;
	GeeHashMap* _tmp6_ = NULL;
	GValue* _tmp7_ = NULL;
	GValue* _tmp8_ = NULL;
	GValue _tmp9_ = {0};
	GValue _tmp10_ = {0};
	GValue* _tmp11_ = NULL;
	GValue* _tmp12_ = NULL;
	GeeHashMap* _tmp13_ = NULL;
	GValue* _tmp14_ = NULL;
	GValue* _tmp15_ = NULL;
	EdsTestBackend* _tmp16_ = NULL;
	GeeHashMap* _tmp17_ = NULL;
	GeeHashMap* _tmp18_ = NULL;
	GeeHashMap* _tmp19_ = NULL;
	GValue _tmp20_ = {0};
	GValue _tmp21_ = {0};
	GValue* _tmp22_ = NULL;
	GValue* _tmp23_ = NULL;
	GeeHashMap* _tmp24_ = NULL;
	GValue* _tmp25_ = NULL;
	GValue* _tmp26_ = NULL;
	GValue _tmp27_ = {0};
	GValue _tmp28_ = {0};
	GValue* _tmp29_ = NULL;
	GValue* _tmp30_ = NULL;
	GeeHashMap* _tmp31_ = NULL;
	GValue* _tmp32_ = NULL;
	GValue* _tmp33_ = NULL;
	EdsTestBackend* _tmp34_ = NULL;
	GeeHashMap* _tmp35_ = NULL;
	GeeHashMap* _tmp36_ = NULL;
	GMainLoop* _tmp37_ = NULL;
	gboolean _tmp38_ = FALSE;
	gboolean _tmp39_ = FALSE;
#line 69 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_return_if_fail (self != NULL);
#line 72 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 72 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 72 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	self->priv->_main_loop = _tmp0_;
#line 75 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	self->priv->_found_before_update = FALSE;
#line 76 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	self->priv->_found_after_update = FALSE;
#line 78 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 78 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (c);
#line 78 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	c = _tmp1_;
#line 79 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_value_init (&_tmp2_, G_TYPE_STRING);
#line 79 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp3_ = _tmp2_;
#line 79 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp4_ = __g_value_dup0 (&_tmp3_);
#line 79 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (v);
#line 79 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	v = _tmp4_;
#line 79 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	G_IS_VALUE (&_tmp3_) ? (g_value_unset (&_tmp3_), NULL) : NULL;
#line 80 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp5_ = v;
#line 80 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_value_set_string (_tmp5_, ANTI_LINKING_TESTS__full_name_1);
#line 81 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp6_ = c;
#line 81 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp7_ = v;
#line 81 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	v = NULL;
#line 81 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp8_ = _tmp7_;
#line 81 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp6_, "full_name", _tmp8_);
#line 81 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (_tmp8_);
#line 82 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_value_init (&_tmp9_, G_TYPE_STRING);
#line 82 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp10_ = _tmp9_;
#line 82 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp11_ = __g_value_dup0 (&_tmp10_);
#line 82 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (v);
#line 82 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	v = _tmp11_;
#line 82 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	G_IS_VALUE (&_tmp10_) ? (g_value_unset (&_tmp10_), NULL) : NULL;
#line 83 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp12_ = v;
#line 83 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_value_set_string (_tmp12_, ANTI_LINKING_TESTS__email_1);
#line 84 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp13_ = c;
#line 84 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp14_ = v;
#line 84 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	v = NULL;
#line 84 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp15_ = _tmp14_;
#line 84 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp13_, "email_1", _tmp15_);
#line 84 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (_tmp15_);
#line 85 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp16_ = ((EdsTestTestCase*) self)->eds_backend;
#line 85 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp17_ = c;
#line 85 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp18_ = _g_object_ref0 (_tmp17_);
#line 85 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	eds_test_backend_add_contact (_tmp16_, _tmp18_);
#line 87 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp19_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 87 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (c);
#line 87 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	c = _tmp19_;
#line 88 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_value_init (&_tmp20_, G_TYPE_STRING);
#line 88 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp21_ = _tmp20_;
#line 88 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp22_ = __g_value_dup0 (&_tmp21_);
#line 88 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (v);
#line 88 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	v = _tmp22_;
#line 88 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	G_IS_VALUE (&_tmp21_) ? (g_value_unset (&_tmp21_), NULL) : NULL;
#line 89 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp23_ = v;
#line 89 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_value_set_string (_tmp23_, ANTI_LINKING_TESTS__full_name_2);
#line 90 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp24_ = c;
#line 90 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp25_ = v;
#line 90 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	v = NULL;
#line 90 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp26_ = _tmp25_;
#line 90 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp24_, "full_name", _tmp26_);
#line 90 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (_tmp26_);
#line 91 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_value_init (&_tmp27_, G_TYPE_STRING);
#line 91 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp28_ = _tmp27_;
#line 91 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp29_ = __g_value_dup0 (&_tmp28_);
#line 91 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (v);
#line 91 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	v = _tmp29_;
#line 91 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	G_IS_VALUE (&_tmp28_) ? (g_value_unset (&_tmp28_), NULL) : NULL;
#line 93 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp30_ = v;
#line 93 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_value_set_string (_tmp30_, ANTI_LINKING_TESTS__email_1);
#line 94 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp31_ = c;
#line 94 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp32_ = v;
#line 94 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	v = NULL;
#line 94 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp33_ = _tmp32_;
#line 94 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp31_, "email_1", _tmp33_);
#line 94 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (_tmp33_);
#line 95 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp34_ = ((EdsTestTestCase*) self)->eds_backend;
#line 95 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp35_ = c;
#line 95 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp36_ = _g_object_ref0 (_tmp35_);
#line 95 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	eds_test_backend_add_contact (_tmp34_, _tmp36_);
#line 97 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_anti_linking_tests_test_anti_linking_basic_async (self, NULL, NULL);
#line 99 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp37_ = self->priv->_main_loop;
#line 99 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	folks_test_utils_loop_run_with_timeout (_tmp37_, 5);
#line 101 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp38_ = self->priv->_found_before_update;
#line 101 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_vala_assert (_tmp38_, "this._found_before_update");
#line 102 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp39_ = self->priv->_found_after_update;
#line 102 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_vala_assert (_tmp39_, "this._found_after_update");
#line 69 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (v);
#line 69 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (c);
#line 454 "anti-linking.c"
}


static void _anti_linking_tests_test_anti_linking_basic_async_data_free (gpointer _data) {
	AntiLinkingTestsTestAntiLinkingBasicAsyncData* _data_;
	_data_ = _data;
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (_data_->self);
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_slice_free (AntiLinkingTestsTestAntiLinkingBasicAsyncData, _data_);
#line 465 "anti-linking.c"
}


static void _anti_linking_tests_test_anti_linking_basic_async (AntiLinkingTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	AntiLinkingTestsTestAntiLinkingBasicAsyncData* _data_;
	AntiLinkingTests* _tmp0_ = NULL;
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_ = g_slice_new0 (AntiLinkingTestsTestAntiLinkingBasicAsyncData);
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _anti_linking_tests_test_anti_linking_basic_async);
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _anti_linking_tests_test_anti_linking_basic_async_data_free);
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->self = _tmp0_;
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_anti_linking_tests_test_anti_linking_basic_async_co (_data_);
#line 484 "anti-linking.c"
}


static void _anti_linking_tests_test_anti_linking_basic_finish (AntiLinkingTests* self, GAsyncResult* _res_) {
	AntiLinkingTestsTestAntiLinkingBasicAsyncData* _data_;
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 492 "anti-linking.c"
}


static void _anti_linking_tests_test_anti_linking_basic_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	AntiLinkingTestsTestAntiLinkingBasicAsyncData* _data_;
#line 107 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_ = _user_data_;
#line 107 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_source_object_ = source_object;
#line 107 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_res_ = _res_;
#line 107 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_anti_linking_tests_test_anti_linking_basic_async_co (_data_);
#line 506 "anti-linking.c"
}


static void __anti_linking_tests_individuals_changed_aggregate_after_change_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 112 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_anti_linking_tests_individuals_changed_aggregate_after_change_cb ((AntiLinkingTests*) self, changes);
#line 513 "anti-linking.c"
}


static gboolean _anti_linking_tests_test_anti_linking_basic_async_co (AntiLinkingTestsTestAntiLinkingBasicAsyncData* _data_) {
#line 105 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	switch (_data_->_state_) {
#line 105 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		case 0:
#line 522 "anti-linking.c"
		goto _state_0;
#line 105 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		case 1:
#line 526 "anti-linking.c"
		goto _state_1;
#line 105 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		case 2:
#line 530 "anti-linking.c"
		goto _state_2;
#line 105 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		case 3:
#line 534 "anti-linking.c"
		goto _state_3;
		default:
#line 105 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		g_assert_not_reached ();
#line 539 "anti-linking.c"
	}
	_state_0:
#line 107 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_tmp0_ = NULL;
#line 107 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_tmp0_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 107 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_state_ = 1;
#line 107 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _anti_linking_tests_test_anti_linking_basic_async_ready, _data_);
#line 107 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	return FALSE;
#line 552 "anti-linking.c"
	_state_1:
#line 107 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 109 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_tmp1_ = NULL;
#line 109 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 109 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->store = _data_->_tmp1_;
#line 110 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_state_ = 2;
#line 110 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	folks_backend_store_prepare (_data_->store, _anti_linking_tests_test_anti_linking_basic_async_ready, _data_);
#line 110 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	return FALSE;
#line 568 "anti-linking.c"
	_state_2:
#line 110 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 111 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_tmp2_ = NULL;
#line 111 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_tmp2_ = folks_individual_aggregator_dup ();
#line 111 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 111 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 112 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_tmp3_ = NULL;
#line 112 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 112 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_signal_connect_object (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) __anti_linking_tests_individuals_changed_aggregate_after_change_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 586 "anti-linking.c"
	{
#line 116 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->_tmp4_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 116 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->_state_ = 3;
#line 116 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		folks_individual_aggregator_prepare (_data_->_tmp4_, _anti_linking_tests_test_anti_linking_basic_async_ready, _data_);
#line 116 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		return FALSE;
#line 598 "anti-linking.c"
		_state_3:
#line 116 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 116 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 604 "anti-linking.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 114 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->e = _data_->_inner_error_;
#line 114 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->_inner_error_ = NULL;
#line 120 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->_tmp5_ = NULL;
#line 120 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->_tmp5_ = _data_->e;
#line 120 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->_tmp6_ = NULL;
#line 120 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 120 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		g_warning ("anti-linking.vala:120: Error when calling prepare: %s\n", _data_->_tmp6_);
#line 114 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_g_error_free0 (_data_->e);
#line 627 "anti-linking.c"
	}
	__finally0:
#line 114 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 114 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_g_object_unref0 (_data_->store);
#line 114 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 114 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		g_clear_error (&_data_->_inner_error_);
#line 114 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		return FALSE;
#line 640 "anti-linking.c"
	}
#line 105 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (_data_->store);
#line 105 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	if (_data_->_state_ == 0) {
#line 105 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 648 "anti-linking.c"
	} else {
#line 105 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 652 "anti-linking.c"
	}
#line 105 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_object_unref (_data_->_async_result);
#line 105 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	return FALSE;
#line 658 "anti-linking.c"
}


static void _anti_linking_tests_individuals_changed_aggregate_after_change_cb (AntiLinkingTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeCollection* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeCollection* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
#line 124 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_return_if_fail (self != NULL);
#line 124 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_return_if_fail (changes != NULL);
#line 127 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp0_ = changes;
#line 127 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 127 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	added = _tmp1_;
#line 128 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp2_ = changes;
#line 128 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp3_ = gee_multi_map_get_values (_tmp2_);
#line 128 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	removed = _tmp3_;
#line 130 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp4_ = self->priv->_found_before_update;
#line 130 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	if (!_tmp4_) {
#line 690 "anti-linking.c"
		GeeMultiMap* _tmp5_ = NULL;
		gint _tmp6_ = 0;
		gint _tmp7_ = 0;
		GeeCollection* _tmp8_ = NULL;
		gint _tmp9_ = 0;
		gint _tmp10_ = 0;
		GeeCollection* _tmp11_ = NULL;
		gint _tmp12_ = 0;
		gint _tmp13_ = 0;
#line 132 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp5_ = changes;
#line 132 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp6_ = gee_multi_map_get_size (_tmp5_);
#line 132 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp7_ = _tmp6_;
#line 132 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_vala_assert (_tmp7_ == 1, "changes.size == 1");
#line 133 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp8_ = added;
#line 133 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp9_ = gee_collection_get_size (_tmp8_);
#line 133 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp10_ = _tmp9_;
#line 133 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_vala_assert (_tmp10_ == 1, "added.size == 1");
#line 134 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp11_ = removed;
#line 134 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp12_ = gee_collection_get_size (_tmp11_);
#line 134 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp13_ = _tmp12_;
#line 134 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_vala_assert (_tmp13_ == 1, "removed.size == 1");
#line 724 "anti-linking.c"
		{
			GeeIterator* _i_it = NULL;
			GeeCollection* _tmp14_ = NULL;
			GeeIterator* _tmp15_ = NULL;
#line 136 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp14_ = added;
#line 136 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp15_ = gee_iterable_iterator ((GeeIterable*) _tmp14_);
#line 136 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_i_it = _tmp15_;
#line 136 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			while (TRUE) {
#line 737 "anti-linking.c"
				GeeIterator* _tmp16_ = NULL;
				gboolean _tmp17_ = FALSE;
				FolksIndividual* i = NULL;
				GeeIterator* _tmp18_ = NULL;
				gpointer _tmp19_ = NULL;
				FolksIndividual* _tmp20_ = NULL;
				FolksIndividual* _tmp21_ = NULL;
				GeeSet* _tmp22_ = NULL;
				GeeSet* _tmp23_ = NULL;
				gint _tmp24_ = 0;
				gint _tmp25_ = 0;
				GeeIterator* iter = NULL;
				FolksIndividual* _tmp26_ = NULL;
				GeeSet* _tmp27_ = NULL;
				GeeSet* _tmp28_ = NULL;
				GeeIterator* _tmp29_ = NULL;
				GeeIterator* _tmp30_ = NULL;
				FolksAntiLinkable* al_1 = NULL;
				GeeIterator* _tmp31_ = NULL;
				gpointer _tmp32_ = NULL;
				FolksPersona* _tmp33_ = NULL;
				FolksAntiLinkable* _tmp34_ = NULL;
				GeeIterator* _tmp35_ = NULL;
				FolksAntiLinkable* al_2 = NULL;
				GeeIterator* _tmp36_ = NULL;
				gpointer _tmp37_ = NULL;
				FolksPersona* _tmp38_ = NULL;
				FolksAntiLinkable* _tmp39_ = NULL;
				GeeHashSet* anti_links = NULL;
				GeeHashSet* _tmp40_ = NULL;
				GeeHashSet* _tmp41_ = NULL;
				FolksAntiLinkable* _tmp42_ = NULL;
				FolksAntiLinkable* _tmp43_ = NULL;
				GeeHashSet* _tmp44_ = NULL;
#line 136 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp16_ = _i_it;
#line 136 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp17_ = gee_iterator_next (_tmp16_);
#line 136 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				if (!_tmp17_) {
#line 136 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					break;
#line 780 "anti-linking.c"
				}
#line 136 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp18_ = _i_it;
#line 136 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp19_ = gee_iterator_get (_tmp18_);
#line 136 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				i = (FolksIndividual*) _tmp19_;
#line 138 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp20_ = i;
#line 138 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_vala_assert (_tmp20_ != NULL, "i != null");
#line 139 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp21_ = i;
#line 139 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp22_ = folks_individual_get_personas (_tmp21_);
#line 139 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp23_ = _tmp22_;
#line 139 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp24_ = gee_collection_get_size ((GeeCollection*) _tmp23_);
#line 139 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp25_ = _tmp24_;
#line 139 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_vala_assert (_tmp25_ == 2, "i.personas.size == 2");
#line 141 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				self->priv->_found_before_update = TRUE;
#line 143 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp26_ = i;
#line 143 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp27_ = folks_individual_get_personas (_tmp26_);
#line 143 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp28_ = _tmp27_;
#line 143 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp29_ = gee_iterable_iterator ((GeeIterable*) _tmp28_);
#line 143 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				iter = _tmp29_;
#line 144 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp30_ = iter;
#line 144 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				gee_iterator_next (_tmp30_);
#line 145 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp31_ = iter;
#line 145 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp32_ = gee_iterator_get (_tmp31_);
#line 145 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp33_ = (FolksPersona*) _tmp32_;
#line 145 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp34_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp33_, FOLKS_TYPE_ANTI_LINKABLE) ? ((FolksAntiLinkable*) _tmp33_) : NULL;
#line 145 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				if (_tmp34_ == NULL) {
#line 145 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_g_object_unref0 (_tmp33_);
#line 832 "anti-linking.c"
				}
#line 145 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				al_1 = _tmp34_;
#line 146 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp35_ = iter;
#line 146 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				gee_iterator_next (_tmp35_);
#line 147 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp36_ = iter;
#line 147 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp37_ = gee_iterator_get (_tmp36_);
#line 147 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp38_ = (FolksPersona*) _tmp37_;
#line 147 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp39_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp38_, FOLKS_TYPE_ANTI_LINKABLE) ? ((FolksAntiLinkable*) _tmp38_) : NULL;
#line 147 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				if (_tmp39_ == NULL) {
#line 147 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_g_object_unref0 (_tmp38_);
#line 852 "anti-linking.c"
				}
#line 147 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				al_2 = _tmp39_;
#line 149 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp40_ = gee_hash_set_new (FOLKS_TYPE_PERSONA, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 149 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				anti_links = _tmp40_;
#line 150 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp41_ = anti_links;
#line 150 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp42_ = al_2;
#line 150 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp41_, (FolksPersona*) _tmp42_);
#line 151 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp43_ = al_1;
#line 151 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp44_ = anti_links;
#line 151 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				folks_anti_linkable_add_anti_links (_tmp43_, (GeeSet*) _tmp44_, NULL, NULL);
#line 136 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_g_object_unref0 (anti_links);
#line 136 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_g_object_unref0 (al_2);
#line 136 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_g_object_unref0 (al_1);
#line 136 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_g_object_unref0 (iter);
#line 136 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_g_object_unref0 (i);
#line 882 "anti-linking.c"
			}
#line 136 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_g_object_unref0 (_i_it);
#line 886 "anti-linking.c"
		}
	} else {
		GeeMultiMap* _tmp45_ = NULL;
		gint _tmp46_ = 0;
		gint _tmp47_ = 0;
		GeeCollection* _tmp48_ = NULL;
		gint _tmp49_ = 0;
		gint _tmp50_ = 0;
		gboolean found_1 = FALSE;
		gboolean found_2 = FALSE;
		gboolean _tmp63_ = FALSE;
		gboolean _tmp64_ = FALSE;
#line 157 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp45_ = changes;
#line 157 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp46_ = gee_multi_map_get_size (_tmp45_);
#line 157 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp47_ = _tmp46_;
#line 157 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_vala_assert (_tmp47_ == 2, "changes.size == 2");
#line 158 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp48_ = added;
#line 158 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp49_ = gee_collection_get_size (_tmp48_);
#line 158 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp50_ = _tmp49_;
#line 158 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_vala_assert (_tmp50_ == 2, "added.size == 2");
#line 160 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		found_1 = FALSE;
#line 161 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		found_2 = FALSE;
#line 919 "anti-linking.c"
		{
			GeeIterator* _i_it = NULL;
			GeeCollection* _tmp51_ = NULL;
			GeeIterator* _tmp52_ = NULL;
#line 163 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp51_ = added;
#line 163 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp52_ = gee_iterable_iterator ((GeeIterable*) _tmp51_);
#line 163 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_i_it = _tmp52_;
#line 163 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			while (TRUE) {
#line 932 "anti-linking.c"
				GeeIterator* _tmp53_ = NULL;
				gboolean _tmp54_ = FALSE;
				FolksIndividual* i = NULL;
				GeeIterator* _tmp55_ = NULL;
				gpointer _tmp56_ = NULL;
				FolksIndividual* _tmp57_ = NULL;
				const gchar* _tmp58_ = NULL;
				const gchar* _tmp59_ = NULL;
				FolksIndividual* _tmp60_ = NULL;
				const gchar* _tmp61_ = NULL;
				const gchar* _tmp62_ = NULL;
#line 163 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp53_ = _i_it;
#line 163 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp54_ = gee_iterator_next (_tmp53_);
#line 163 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				if (!_tmp54_) {
#line 163 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					break;
#line 952 "anti-linking.c"
				}
#line 163 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp55_ = _i_it;
#line 163 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp56_ = gee_iterator_get (_tmp55_);
#line 163 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				i = (FolksIndividual*) _tmp56_;
#line 165 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp57_ = i;
#line 165 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp58_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp57_);
#line 165 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp59_ = _tmp58_;
#line 165 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				if (g_strcmp0 (_tmp59_, ANTI_LINKING_TESTS__full_name_1) == 0) {
#line 167 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					found_1 = TRUE;
#line 970 "anti-linking.c"
				}
#line 169 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp60_ = i;
#line 169 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp61_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp60_);
#line 169 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp62_ = _tmp61_;
#line 169 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				if (g_strcmp0 (_tmp62_, ANTI_LINKING_TESTS__full_name_2) == 0) {
#line 171 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					found_2 = TRUE;
#line 982 "anti-linking.c"
				}
#line 163 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_g_object_unref0 (i);
#line 986 "anti-linking.c"
			}
#line 163 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_g_object_unref0 (_i_it);
#line 990 "anti-linking.c"
		}
#line 175 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp64_ = found_1;
#line 175 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		if (_tmp64_) {
#line 996 "anti-linking.c"
			gboolean _tmp65_ = FALSE;
#line 175 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp65_ = found_2;
#line 175 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp63_ = _tmp65_;
#line 1002 "anti-linking.c"
		} else {
#line 175 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp63_ = FALSE;
#line 1006 "anti-linking.c"
		}
#line 175 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		if (_tmp63_) {
#line 1010 "anti-linking.c"
			GMainLoop* _tmp66_ = NULL;
#line 177 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			self->priv->_found_after_update = TRUE;
#line 178 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp66_ = self->priv->_main_loop;
#line 178 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			g_main_loop_quit (_tmp66_);
#line 1018 "anti-linking.c"
		}
	}
#line 124 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (removed);
#line 124 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (added);
#line 1025 "anti-linking.c"
}


static void anti_linking_tests_test_anti_linking_removal (AntiLinkingTests* self) {
	GeeHashMap* c = NULL;
	GMainLoop* _tmp0_ = NULL;
	GValue* v = NULL;
	GeeHashMap* _tmp1_ = NULL;
	GValue _tmp2_ = {0};
	GValue _tmp3_ = {0};
	GValue* _tmp4_ = NULL;
	GValue* _tmp5_ = NULL;
	GeeHashMap* _tmp6_ = NULL;
	GValue* _tmp7_ = NULL;
	GValue* _tmp8_ = NULL;
	GValue _tmp9_ = {0};
	GValue _tmp10_ = {0};
	GValue* _tmp11_ = NULL;
	GValue* _tmp12_ = NULL;
	GeeHashMap* _tmp13_ = NULL;
	GValue* _tmp14_ = NULL;
	GValue* _tmp15_ = NULL;
	EdsTestBackend* _tmp16_ = NULL;
	GeeHashMap* _tmp17_ = NULL;
	GeeHashMap* _tmp18_ = NULL;
	GeeHashMap* _tmp19_ = NULL;
	GValue _tmp20_ = {0};
	GValue _tmp21_ = {0};
	GValue* _tmp22_ = NULL;
	GValue* _tmp23_ = NULL;
	GeeHashMap* _tmp24_ = NULL;
	GValue* _tmp25_ = NULL;
	GValue* _tmp26_ = NULL;
	GValue _tmp27_ = {0};
	GValue _tmp28_ = {0};
	GValue* _tmp29_ = NULL;
	GValue* _tmp30_ = NULL;
	GeeHashMap* _tmp31_ = NULL;
	GValue* _tmp32_ = NULL;
	GValue* _tmp33_ = NULL;
	EdsTestBackend* _tmp34_ = NULL;
	GeeHashMap* _tmp35_ = NULL;
	GeeHashMap* _tmp36_ = NULL;
	GMainLoop* _tmp37_ = NULL;
	gboolean _tmp38_ = FALSE;
	gboolean _tmp39_ = FALSE;
	gboolean _tmp40_ = FALSE;
#line 189 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_return_if_fail (self != NULL);
#line 192 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 192 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 192 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	self->priv->_main_loop = _tmp0_;
#line 195 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	self->priv->_found_before_update = FALSE;
#line 196 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	self->priv->_found_after_update = FALSE;
#line 198 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 198 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (c);
#line 198 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	c = _tmp1_;
#line 199 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_value_init (&_tmp2_, G_TYPE_STRING);
#line 199 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp3_ = _tmp2_;
#line 199 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp4_ = __g_value_dup0 (&_tmp3_);
#line 199 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (v);
#line 199 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	v = _tmp4_;
#line 199 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	G_IS_VALUE (&_tmp3_) ? (g_value_unset (&_tmp3_), NULL) : NULL;
#line 200 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp5_ = v;
#line 200 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_value_set_string (_tmp5_, ANTI_LINKING_TESTS__full_name_1);
#line 201 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp6_ = c;
#line 201 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp7_ = v;
#line 201 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	v = NULL;
#line 201 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp8_ = _tmp7_;
#line 201 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp6_, "full_name", _tmp8_);
#line 201 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (_tmp8_);
#line 202 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_value_init (&_tmp9_, G_TYPE_STRING);
#line 202 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp10_ = _tmp9_;
#line 202 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp11_ = __g_value_dup0 (&_tmp10_);
#line 202 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (v);
#line 202 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	v = _tmp11_;
#line 202 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	G_IS_VALUE (&_tmp10_) ? (g_value_unset (&_tmp10_), NULL) : NULL;
#line 203 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp12_ = v;
#line 203 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_value_set_string (_tmp12_, ANTI_LINKING_TESTS__email_1);
#line 204 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp13_ = c;
#line 204 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp14_ = v;
#line 204 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	v = NULL;
#line 204 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp15_ = _tmp14_;
#line 204 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp13_, "email_1", _tmp15_);
#line 204 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (_tmp15_);
#line 205 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp16_ = ((EdsTestTestCase*) self)->eds_backend;
#line 205 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp17_ = c;
#line 205 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp18_ = _g_object_ref0 (_tmp17_);
#line 205 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	eds_test_backend_add_contact (_tmp16_, _tmp18_);
#line 207 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp19_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 207 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (c);
#line 207 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	c = _tmp19_;
#line 208 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_value_init (&_tmp20_, G_TYPE_STRING);
#line 208 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp21_ = _tmp20_;
#line 208 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp22_ = __g_value_dup0 (&_tmp21_);
#line 208 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (v);
#line 208 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	v = _tmp22_;
#line 208 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	G_IS_VALUE (&_tmp21_) ? (g_value_unset (&_tmp21_), NULL) : NULL;
#line 209 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp23_ = v;
#line 209 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_value_set_string (_tmp23_, ANTI_LINKING_TESTS__full_name_2);
#line 210 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp24_ = c;
#line 210 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp25_ = v;
#line 210 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	v = NULL;
#line 210 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp26_ = _tmp25_;
#line 210 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp24_, "full_name", _tmp26_);
#line 210 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (_tmp26_);
#line 211 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_value_init (&_tmp27_, G_TYPE_STRING);
#line 211 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp28_ = _tmp27_;
#line 211 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp29_ = __g_value_dup0 (&_tmp28_);
#line 211 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (v);
#line 211 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	v = _tmp29_;
#line 211 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	G_IS_VALUE (&_tmp28_) ? (g_value_unset (&_tmp28_), NULL) : NULL;
#line 213 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp30_ = v;
#line 213 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_value_set_string (_tmp30_, ANTI_LINKING_TESTS__email_1);
#line 214 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp31_ = c;
#line 214 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp32_ = v;
#line 214 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	v = NULL;
#line 214 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp33_ = _tmp32_;
#line 214 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp31_, "email_1", _tmp33_);
#line 214 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (_tmp33_);
#line 215 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp34_ = ((EdsTestTestCase*) self)->eds_backend;
#line 215 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp35_ = c;
#line 215 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp36_ = _g_object_ref0 (_tmp35_);
#line 215 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	eds_test_backend_add_contact (_tmp34_, _tmp36_);
#line 217 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_anti_linking_tests_test_anti_linking_removal_async (self, NULL, NULL);
#line 219 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp37_ = self->priv->_main_loop;
#line 219 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	folks_test_utils_loop_run_with_timeout (_tmp37_, 5);
#line 221 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp38_ = self->priv->_found_before_update;
#line 221 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_vala_assert (_tmp38_, "this._found_before_update");
#line 222 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp39_ = self->priv->_found_after_update;
#line 222 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_vala_assert (_tmp39_, "this._found_after_update");
#line 223 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp40_ = self->priv->_found_after_final_update;
#line 223 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_vala_assert (_tmp40_, "this._found_after_final_update");
#line 189 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	__vala_GValue_free0 (v);
#line 189 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (c);
#line 1247 "anti-linking.c"
}


static void _anti_linking_tests_test_anti_linking_removal_async_data_free (gpointer _data) {
	AntiLinkingTestsTestAntiLinkingRemovalAsyncData* _data_;
	_data_ = _data;
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (_data_->self);
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_slice_free (AntiLinkingTestsTestAntiLinkingRemovalAsyncData, _data_);
#line 1258 "anti-linking.c"
}


static void _anti_linking_tests_test_anti_linking_removal_async (AntiLinkingTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	AntiLinkingTestsTestAntiLinkingRemovalAsyncData* _data_;
	AntiLinkingTests* _tmp0_ = NULL;
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_ = g_slice_new0 (AntiLinkingTestsTestAntiLinkingRemovalAsyncData);
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _anti_linking_tests_test_anti_linking_removal_async);
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _anti_linking_tests_test_anti_linking_removal_async_data_free);
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->self = _tmp0_;
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_anti_linking_tests_test_anti_linking_removal_async_co (_data_);
#line 1277 "anti-linking.c"
}


static void _anti_linking_tests_test_anti_linking_removal_finish (AntiLinkingTests* self, GAsyncResult* _res_) {
	AntiLinkingTestsTestAntiLinkingRemovalAsyncData* _data_;
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1285 "anti-linking.c"
}


static void _anti_linking_tests_test_anti_linking_removal_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	AntiLinkingTestsTestAntiLinkingRemovalAsyncData* _data_;
#line 228 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_ = _user_data_;
#line 228 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_source_object_ = source_object;
#line 228 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_res_ = _res_;
#line 228 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_anti_linking_tests_test_anti_linking_removal_async_co (_data_);
#line 1299 "anti-linking.c"
}


static void __anti_linking_tests_individuals_changed_anti_linking_removal_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 233 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_anti_linking_tests_individuals_changed_anti_linking_removal_cb ((AntiLinkingTests*) self, changes);
#line 1306 "anti-linking.c"
}


static gboolean _anti_linking_tests_test_anti_linking_removal_async_co (AntiLinkingTestsTestAntiLinkingRemovalAsyncData* _data_) {
#line 226 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	switch (_data_->_state_) {
#line 226 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		case 0:
#line 1315 "anti-linking.c"
		goto _state_0;
#line 226 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		case 1:
#line 1319 "anti-linking.c"
		goto _state_1;
#line 226 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		case 2:
#line 1323 "anti-linking.c"
		goto _state_2;
#line 226 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		case 3:
#line 1327 "anti-linking.c"
		goto _state_3;
		default:
#line 226 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		g_assert_not_reached ();
#line 1332 "anti-linking.c"
	}
	_state_0:
#line 228 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_tmp0_ = NULL;
#line 228 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_tmp0_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 228 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_state_ = 1;
#line 228 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _anti_linking_tests_test_anti_linking_removal_async_ready, _data_);
#line 228 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	return FALSE;
#line 1345 "anti-linking.c"
	_state_1:
#line 228 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 230 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_tmp1_ = NULL;
#line 230 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 230 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->store = _data_->_tmp1_;
#line 231 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_state_ = 2;
#line 231 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	folks_backend_store_prepare (_data_->store, _anti_linking_tests_test_anti_linking_removal_async_ready, _data_);
#line 231 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	return FALSE;
#line 1361 "anti-linking.c"
	_state_2:
#line 231 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 232 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_tmp2_ = NULL;
#line 232 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_tmp2_ = folks_individual_aggregator_dup ();
#line 232 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 232 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 233 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_tmp3_ = NULL;
#line 233 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 233 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_signal_connect_object (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) __anti_linking_tests_individuals_changed_anti_linking_removal_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 1379 "anti-linking.c"
	{
#line 237 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->_tmp4_ = NULL;
#line 237 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 237 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->_state_ = 3;
#line 237 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		folks_individual_aggregator_prepare (_data_->_tmp4_, _anti_linking_tests_test_anti_linking_removal_async_ready, _data_);
#line 237 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		return FALSE;
#line 1391 "anti-linking.c"
		_state_3:
#line 237 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 237 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1397 "anti-linking.c"
			goto __catch1_g_error;
		}
	}
	goto __finally1;
	__catch1_g_error:
	{
#line 235 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->e = _data_->_inner_error_;
#line 235 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->_inner_error_ = NULL;
#line 241 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->_tmp5_ = NULL;
#line 241 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->_tmp5_ = _data_->e;
#line 241 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->_tmp6_ = NULL;
#line 241 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 241 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		g_warning ("anti-linking.vala:241: Error when calling prepare: %s\n", _data_->_tmp6_);
#line 235 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_g_error_free0 (_data_->e);
#line 1420 "anti-linking.c"
	}
	__finally1:
#line 235 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 235 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_g_object_unref0 (_data_->store);
#line 235 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 235 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		g_clear_error (&_data_->_inner_error_);
#line 235 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		return FALSE;
#line 1433 "anti-linking.c"
	}
#line 226 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (_data_->store);
#line 226 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	if (_data_->_state_ == 0) {
#line 226 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1441 "anti-linking.c"
	} else {
#line 226 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1445 "anti-linking.c"
	}
#line 226 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_object_unref (_data_->_async_result);
#line 226 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	return FALSE;
#line 1451 "anti-linking.c"
}


static void _anti_linking_tests_individuals_changed_anti_linking_removal_cb (AntiLinkingTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeCollection* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeCollection* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
#line 245 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_return_if_fail (self != NULL);
#line 245 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_return_if_fail (changes != NULL);
#line 248 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp0_ = changes;
#line 248 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 248 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	added = _tmp1_;
#line 249 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp2_ = changes;
#line 249 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp3_ = gee_multi_map_get_values (_tmp2_);
#line 249 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	removed = _tmp3_;
#line 251 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp4_ = self->priv->_found_before_update;
#line 251 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	if (!_tmp4_) {
#line 1483 "anti-linking.c"
		GeeMultiMap* _tmp5_ = NULL;
		gint _tmp6_ = 0;
		gint _tmp7_ = 0;
		GeeCollection* _tmp8_ = NULL;
		gint _tmp9_ = 0;
		gint _tmp10_ = 0;
		GeeCollection* _tmp11_ = NULL;
		gint _tmp12_ = 0;
		gint _tmp13_ = 0;
#line 253 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp5_ = changes;
#line 253 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp6_ = gee_multi_map_get_size (_tmp5_);
#line 253 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp7_ = _tmp6_;
#line 253 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_vala_assert (_tmp7_ == 1, "changes.size == 1");
#line 254 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp8_ = added;
#line 254 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp9_ = gee_collection_get_size (_tmp8_);
#line 254 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp10_ = _tmp9_;
#line 254 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_vala_assert (_tmp10_ == 1, "added.size == 1");
#line 255 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp11_ = removed;
#line 255 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp12_ = gee_collection_get_size (_tmp11_);
#line 255 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp13_ = _tmp12_;
#line 255 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_vala_assert (_tmp13_ == 1, "removed.size == 1");
#line 1517 "anti-linking.c"
		{
			GeeIterator* _i_it = NULL;
			GeeCollection* _tmp14_ = NULL;
			GeeIterator* _tmp15_ = NULL;
#line 257 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp14_ = added;
#line 257 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp15_ = gee_iterable_iterator ((GeeIterable*) _tmp14_);
#line 257 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_i_it = _tmp15_;
#line 257 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			while (TRUE) {
#line 1530 "anti-linking.c"
				GeeIterator* _tmp16_ = NULL;
				gboolean _tmp17_ = FALSE;
				FolksIndividual* i = NULL;
				GeeIterator* _tmp18_ = NULL;
				gpointer _tmp19_ = NULL;
				FolksIndividual* _tmp20_ = NULL;
				FolksIndividual* _tmp21_ = NULL;
				GeeSet* _tmp22_ = NULL;
				GeeSet* _tmp23_ = NULL;
				gint _tmp24_ = 0;
				gint _tmp25_ = 0;
				GeeIterator* iter = NULL;
				FolksIndividual* _tmp26_ = NULL;
				GeeSet* _tmp27_ = NULL;
				GeeSet* _tmp28_ = NULL;
				GeeIterator* _tmp29_ = NULL;
				GeeIterator* _tmp30_ = NULL;
				FolksAntiLinkable* al_1 = NULL;
				GeeIterator* _tmp31_ = NULL;
				gpointer _tmp32_ = NULL;
				FolksPersona* _tmp33_ = NULL;
				FolksAntiLinkable* _tmp34_ = NULL;
				GeeIterator* _tmp35_ = NULL;
				FolksAntiLinkable* al_2 = NULL;
				GeeIterator* _tmp36_ = NULL;
				gpointer _tmp37_ = NULL;
				FolksPersona* _tmp38_ = NULL;
				FolksAntiLinkable* _tmp39_ = NULL;
				GeeHashSet* anti_links = NULL;
				GeeHashSet* _tmp40_ = NULL;
				GeeHashSet* _tmp41_ = NULL;
				FolksAntiLinkable* _tmp42_ = NULL;
				FolksAntiLinkable* _tmp43_ = NULL;
				GeeHashSet* _tmp44_ = NULL;
#line 257 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp16_ = _i_it;
#line 257 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp17_ = gee_iterator_next (_tmp16_);
#line 257 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				if (!_tmp17_) {
#line 257 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					break;
#line 1573 "anti-linking.c"
				}
#line 257 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp18_ = _i_it;
#line 257 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp19_ = gee_iterator_get (_tmp18_);
#line 257 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				i = (FolksIndividual*) _tmp19_;
#line 259 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp20_ = i;
#line 259 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_vala_assert (_tmp20_ != NULL, "i != null");
#line 260 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp21_ = i;
#line 260 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp22_ = folks_individual_get_personas (_tmp21_);
#line 260 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp23_ = _tmp22_;
#line 260 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp24_ = gee_collection_get_size ((GeeCollection*) _tmp23_);
#line 260 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp25_ = _tmp24_;
#line 260 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_vala_assert (_tmp25_ == 2, "i.personas.size == 2");
#line 262 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				self->priv->_found_before_update = TRUE;
#line 264 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp26_ = i;
#line 264 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp27_ = folks_individual_get_personas (_tmp26_);
#line 264 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp28_ = _tmp27_;
#line 264 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp29_ = gee_iterable_iterator ((GeeIterable*) _tmp28_);
#line 264 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				iter = _tmp29_;
#line 265 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp30_ = iter;
#line 265 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				gee_iterator_next (_tmp30_);
#line 266 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp31_ = iter;
#line 266 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp32_ = gee_iterator_get (_tmp31_);
#line 266 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp33_ = (FolksPersona*) _tmp32_;
#line 266 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp34_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp33_, FOLKS_TYPE_ANTI_LINKABLE) ? ((FolksAntiLinkable*) _tmp33_) : NULL;
#line 266 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				if (_tmp34_ == NULL) {
#line 266 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_g_object_unref0 (_tmp33_);
#line 1625 "anti-linking.c"
				}
#line 266 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				al_1 = _tmp34_;
#line 267 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp35_ = iter;
#line 267 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				gee_iterator_next (_tmp35_);
#line 268 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp36_ = iter;
#line 268 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp37_ = gee_iterator_get (_tmp36_);
#line 268 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp38_ = (FolksPersona*) _tmp37_;
#line 268 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp39_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp38_, FOLKS_TYPE_ANTI_LINKABLE) ? ((FolksAntiLinkable*) _tmp38_) : NULL;
#line 268 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				if (_tmp39_ == NULL) {
#line 268 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_g_object_unref0 (_tmp38_);
#line 1645 "anti-linking.c"
				}
#line 268 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				al_2 = _tmp39_;
#line 270 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp40_ = gee_hash_set_new (FOLKS_TYPE_PERSONA, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 270 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				anti_links = _tmp40_;
#line 271 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp41_ = anti_links;
#line 271 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp42_ = al_2;
#line 271 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp41_, (FolksPersona*) _tmp42_);
#line 272 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp43_ = al_1;
#line 272 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp44_ = anti_links;
#line 272 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				folks_anti_linkable_add_anti_links (_tmp43_, (GeeSet*) _tmp44_, NULL, NULL);
#line 257 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_g_object_unref0 (anti_links);
#line 257 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_g_object_unref0 (al_2);
#line 257 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_g_object_unref0 (al_1);
#line 257 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_g_object_unref0 (iter);
#line 257 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_g_object_unref0 (i);
#line 1675 "anti-linking.c"
			}
#line 257 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_g_object_unref0 (_i_it);
#line 1679 "anti-linking.c"
		}
	} else {
		gboolean _tmp45_ = FALSE;
#line 275 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		_tmp45_ = self->priv->_found_after_update;
#line 275 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
		if (!_tmp45_) {
#line 1687 "anti-linking.c"
			GeeMultiMap* _tmp46_ = NULL;
			gint _tmp47_ = 0;
			gint _tmp48_ = 0;
			GeeCollection* _tmp49_ = NULL;
			gint _tmp50_ = 0;
			gint _tmp51_ = 0;
			FolksIndividual* ind_1 = NULL;
			FolksIndividual* ind_2 = NULL;
			FolksIndividual* _tmp68_ = NULL;
			FolksIndividual* _tmp69_ = NULL;
			GeeIterator* iter = NULL;
			FolksIndividual* _tmp70_ = NULL;
			GeeSet* _tmp71_ = NULL;
			GeeSet* _tmp72_ = NULL;
			GeeIterator* _tmp73_ = NULL;
			GeeIterator* _tmp74_ = NULL;
			FolksAntiLinkable* al_1 = NULL;
			GeeIterator* _tmp75_ = NULL;
			gpointer _tmp76_ = NULL;
			FolksPersona* _tmp77_ = NULL;
			FolksAntiLinkable* _tmp78_ = NULL;
			FolksIndividual* _tmp79_ = NULL;
			GeeSet* _tmp80_ = NULL;
			GeeSet* _tmp81_ = NULL;
			GeeIterator* _tmp82_ = NULL;
			GeeIterator* _tmp83_ = NULL;
			FolksAntiLinkable* al_2 = NULL;
			GeeIterator* _tmp84_ = NULL;
			gpointer _tmp85_ = NULL;
			FolksPersona* _tmp86_ = NULL;
			FolksAntiLinkable* _tmp87_ = NULL;
			GeeHashSet* anti_links = NULL;
			GeeHashSet* _tmp88_ = NULL;
			GeeHashSet* _tmp89_ = NULL;
			FolksAntiLinkable* _tmp90_ = NULL;
			FolksAntiLinkable* _tmp91_ = NULL;
			GeeHashSet* _tmp92_ = NULL;
			GeeHashSet* _tmp93_ = NULL;
			GeeHashSet* _tmp94_ = NULL;
			FolksAntiLinkable* _tmp95_ = NULL;
			FolksAntiLinkable* _tmp96_ = NULL;
			GeeHashSet* _tmp97_ = NULL;
#line 278 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp46_ = changes;
#line 278 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp47_ = gee_multi_map_get_size (_tmp46_);
#line 278 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp48_ = _tmp47_;
#line 278 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_vala_assert (_tmp48_ == 2, "changes.size == 2");
#line 279 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp49_ = added;
#line 279 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp50_ = gee_collection_get_size (_tmp49_);
#line 279 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp51_ = _tmp50_;
#line 279 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_vala_assert (_tmp51_ == 2, "added.size == 2");
#line 281 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			ind_1 = NULL;
#line 282 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			ind_2 = NULL;
#line 1750 "anti-linking.c"
			{
				GeeIterator* _i_it = NULL;
				GeeCollection* _tmp52_ = NULL;
				GeeIterator* _tmp53_ = NULL;
#line 284 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp52_ = added;
#line 284 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp53_ = gee_iterable_iterator ((GeeIterable*) _tmp52_);
#line 284 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_i_it = _tmp53_;
#line 284 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				while (TRUE) {
#line 1763 "anti-linking.c"
					GeeIterator* _tmp54_ = NULL;
					gboolean _tmp55_ = FALSE;
					FolksIndividual* i = NULL;
					GeeIterator* _tmp56_ = NULL;
					gpointer _tmp57_ = NULL;
					FolksIndividual* _tmp58_ = NULL;
					const gchar* _tmp59_ = NULL;
					const gchar* _tmp60_ = NULL;
					FolksIndividual* _tmp63_ = NULL;
					const gchar* _tmp64_ = NULL;
					const gchar* _tmp65_ = NULL;
#line 284 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_tmp54_ = _i_it;
#line 284 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_tmp55_ = gee_iterator_next (_tmp54_);
#line 284 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					if (!_tmp55_) {
#line 284 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
						break;
#line 1783 "anti-linking.c"
					}
#line 284 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_tmp56_ = _i_it;
#line 284 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_tmp57_ = gee_iterator_get (_tmp56_);
#line 284 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					i = (FolksIndividual*) _tmp57_;
#line 286 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_tmp58_ = i;
#line 286 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_tmp59_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp58_);
#line 286 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_tmp60_ = _tmp59_;
#line 286 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					if (g_strcmp0 (_tmp60_, ANTI_LINKING_TESTS__full_name_1) == 0) {
#line 1799 "anti-linking.c"
						FolksIndividual* _tmp61_ = NULL;
						FolksIndividual* _tmp62_ = NULL;
#line 288 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
						_tmp61_ = i;
#line 288 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
						_tmp62_ = _g_object_ref0 (_tmp61_);
#line 288 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
						_g_object_unref0 (ind_1);
#line 288 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
						ind_1 = _tmp62_;
#line 1810 "anti-linking.c"
					}
#line 290 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_tmp63_ = i;
#line 290 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_tmp64_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp63_);
#line 290 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_tmp65_ = _tmp64_;
#line 290 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					if (g_strcmp0 (_tmp65_, ANTI_LINKING_TESTS__full_name_2) == 0) {
#line 1820 "anti-linking.c"
						FolksIndividual* _tmp66_ = NULL;
						FolksIndividual* _tmp67_ = NULL;
#line 292 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
						_tmp66_ = i;
#line 292 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
						_tmp67_ = _g_object_ref0 (_tmp66_);
#line 292 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
						_g_object_unref0 (ind_2);
#line 292 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
						ind_2 = _tmp67_;
#line 1831 "anti-linking.c"
					}
#line 284 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_g_object_unref0 (i);
#line 1835 "anti-linking.c"
				}
#line 284 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_g_object_unref0 (_i_it);
#line 1839 "anti-linking.c"
			}
#line 296 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp68_ = ind_1;
#line 296 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_vala_assert (_tmp68_ != NULL, "ind_1 != null");
#line 297 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp69_ = ind_2;
#line 297 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_vala_assert (_tmp69_ != NULL, "ind_2 != null");
#line 299 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			self->priv->_found_after_update = TRUE;
#line 302 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp70_ = ind_1;
#line 302 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp71_ = folks_individual_get_personas (_tmp70_);
#line 302 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp72_ = _tmp71_;
#line 302 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp73_ = gee_iterable_iterator ((GeeIterable*) _tmp72_);
#line 302 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_g_object_unref0 (iter);
#line 302 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			iter = _tmp73_;
#line 303 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp74_ = iter;
#line 303 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			gee_iterator_next (_tmp74_);
#line 304 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp75_ = iter;
#line 304 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp76_ = gee_iterator_get (_tmp75_);
#line 304 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp77_ = (FolksPersona*) _tmp76_;
#line 304 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp78_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp77_, FOLKS_TYPE_ANTI_LINKABLE) ? ((FolksAntiLinkable*) _tmp77_) : NULL;
#line 304 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			if (_tmp78_ == NULL) {
#line 304 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_g_object_unref0 (_tmp77_);
#line 1879 "anti-linking.c"
			}
#line 304 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			al_1 = _tmp78_;
#line 306 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp79_ = ind_2;
#line 306 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp80_ = folks_individual_get_personas (_tmp79_);
#line 306 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp81_ = _tmp80_;
#line 306 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp82_ = gee_iterable_iterator ((GeeIterable*) _tmp81_);
#line 306 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_g_object_unref0 (iter);
#line 306 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			iter = _tmp82_;
#line 307 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp83_ = iter;
#line 307 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			gee_iterator_next (_tmp83_);
#line 308 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp84_ = iter;
#line 308 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp85_ = gee_iterator_get (_tmp84_);
#line 308 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp86_ = (FolksPersona*) _tmp85_;
#line 308 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp87_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp86_, FOLKS_TYPE_ANTI_LINKABLE) ? ((FolksAntiLinkable*) _tmp86_) : NULL;
#line 308 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			if (_tmp87_ == NULL) {
#line 308 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_g_object_unref0 (_tmp86_);
#line 1911 "anti-linking.c"
			}
#line 308 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			al_2 = _tmp87_;
#line 312 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp88_ = gee_hash_set_new (FOLKS_TYPE_PERSONA, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 312 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_g_object_unref0 (anti_links);
#line 312 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			anti_links = _tmp88_;
#line 313 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp89_ = anti_links;
#line 313 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp90_ = al_2;
#line 313 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp89_, (FolksPersona*) _tmp90_);
#line 314 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp91_ = al_1;
#line 314 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp92_ = anti_links;
#line 314 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			folks_anti_linkable_remove_anti_links (_tmp91_, (GeeSet*) _tmp92_, NULL, NULL);
#line 316 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp93_ = gee_hash_set_new (FOLKS_TYPE_PERSONA, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 316 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_g_object_unref0 (anti_links);
#line 316 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			anti_links = _tmp93_;
#line 317 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp94_ = anti_links;
#line 317 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp95_ = al_1;
#line 317 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp94_, (FolksPersona*) _tmp95_);
#line 318 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp96_ = al_2;
#line 318 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp97_ = anti_links;
#line 318 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			folks_anti_linkable_remove_anti_links (_tmp96_, (GeeSet*) _tmp97_, NULL, NULL);
#line 275 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_g_object_unref0 (anti_links);
#line 275 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_g_object_unref0 (al_2);
#line 275 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_g_object_unref0 (al_1);
#line 275 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_g_object_unref0 (iter);
#line 275 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_g_object_unref0 (ind_2);
#line 275 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_g_object_unref0 (ind_1);
#line 1963 "anti-linking.c"
		} else {
			GeeCollection* _tmp98_ = NULL;
			gint _tmp99_ = 0;
			gint _tmp100_ = 0;
			GeeHashSet* added_unique = NULL;
			GeeHashSet* _tmp101_ = NULL;
			GeeHashSet* _tmp102_ = NULL;
			GeeCollection* _tmp103_ = NULL;
			GeeHashSet* _tmp104_ = NULL;
			gint _tmp105_ = 0;
			gint _tmp106_ = 0;
			gboolean found_1 = FALSE;
			gboolean found_2 = FALSE;
			gboolean _tmp127_ = FALSE;
			gboolean _tmp128_ = FALSE;
#line 323 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp98_ = removed;
#line 323 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp99_ = gee_collection_get_size (_tmp98_);
#line 323 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp100_ = _tmp99_;
#line 323 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_vala_assert (_tmp100_ == 2, "removed.size == 2");
#line 324 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp101_ = gee_hash_set_new (FOLKS_TYPE_INDIVIDUAL, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 324 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			added_unique = _tmp101_;
#line 325 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp102_ = added_unique;
#line 325 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp103_ = added;
#line 325 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			gee_collection_add_all ((GeeCollection*) _tmp102_, _tmp103_);
#line 326 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp104_ = added_unique;
#line 326 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp105_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp104_);
#line 326 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp106_ = _tmp105_;
#line 326 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_vala_assert (_tmp106_ == 1, "added_unique.size == 1");
#line 328 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			found_1 = FALSE;
#line 329 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			found_2 = FALSE;
#line 2009 "anti-linking.c"
			{
				GeeIterator* _i_it = NULL;
				GeeCollection* _tmp107_ = NULL;
				GeeIterator* _tmp108_ = NULL;
#line 332 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp107_ = added;
#line 332 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp108_ = gee_iterable_iterator ((GeeIterable*) _tmp107_);
#line 332 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_i_it = _tmp108_;
#line 332 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				while (TRUE) {
#line 2022 "anti-linking.c"
					GeeIterator* _tmp109_ = NULL;
					gboolean _tmp110_ = FALSE;
					FolksIndividual* i = NULL;
					GeeIterator* _tmp111_ = NULL;
					gpointer _tmp112_ = NULL;
#line 332 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_tmp109_ = _i_it;
#line 332 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_tmp110_ = gee_iterator_next (_tmp109_);
#line 332 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					if (!_tmp110_) {
#line 332 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
						break;
#line 2036 "anti-linking.c"
					}
#line 332 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_tmp111_ = _i_it;
#line 332 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_tmp112_ = gee_iterator_get (_tmp111_);
#line 332 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					i = (FolksIndividual*) _tmp112_;
#line 2044 "anti-linking.c"
					{
						GeeIterator* _p_it = NULL;
						FolksIndividual* _tmp113_ = NULL;
						GeeSet* _tmp114_ = NULL;
						GeeSet* _tmp115_ = NULL;
						GeeIterator* _tmp116_ = NULL;
#line 334 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
						_tmp113_ = i;
#line 334 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
						_tmp114_ = folks_individual_get_personas (_tmp113_);
#line 334 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
						_tmp115_ = _tmp114_;
#line 334 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
						_tmp116_ = gee_iterable_iterator ((GeeIterable*) _tmp115_);
#line 334 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
						_p_it = _tmp116_;
#line 334 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
						while (TRUE) {
#line 2063 "anti-linking.c"
							GeeIterator* _tmp117_ = NULL;
							gboolean _tmp118_ = FALSE;
							FolksPersona* p = NULL;
							GeeIterator* _tmp119_ = NULL;
							gpointer _tmp120_ = NULL;
							FolksPersona* _tmp121_ = NULL;
							const gchar* _tmp122_ = NULL;
							const gchar* _tmp123_ = NULL;
							FolksPersona* _tmp124_ = NULL;
							const gchar* _tmp125_ = NULL;
							const gchar* _tmp126_ = NULL;
#line 334 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
							_tmp117_ = _p_it;
#line 334 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
							_tmp118_ = gee_iterator_next (_tmp117_);
#line 334 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
							if (!_tmp118_) {
#line 334 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
								break;
#line 2083 "anti-linking.c"
							}
#line 334 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
							_tmp119_ = _p_it;
#line 334 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
							_tmp120_ = gee_iterator_get (_tmp119_);
#line 334 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
							p = (FolksPersona*) _tmp120_;
#line 336 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
							_tmp121_ = p;
#line 336 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
							_tmp122_ = folks_name_details_get_full_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp121_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 336 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
							_tmp123_ = _tmp122_;
#line 336 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
							if (g_strcmp0 (_tmp123_, ANTI_LINKING_TESTS__full_name_1) == 0) {
#line 338 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
								found_1 = TRUE;
#line 2101 "anti-linking.c"
							}
#line 340 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
							_tmp124_ = p;
#line 340 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
							_tmp125_ = folks_name_details_get_full_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp124_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 340 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
							_tmp126_ = _tmp125_;
#line 340 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
							if (g_strcmp0 (_tmp126_, ANTI_LINKING_TESTS__full_name_2) == 0) {
#line 342 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
								found_2 = TRUE;
#line 2113 "anti-linking.c"
							}
#line 334 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
							_g_object_unref0 (p);
#line 2117 "anti-linking.c"
						}
#line 334 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
						_g_object_unref0 (_p_it);
#line 2121 "anti-linking.c"
					}
#line 332 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
					_g_object_unref0 (i);
#line 2125 "anti-linking.c"
				}
#line 332 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_g_object_unref0 (_i_it);
#line 2129 "anti-linking.c"
			}
#line 347 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_tmp128_ = found_1;
#line 347 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			if (_tmp128_) {
#line 2135 "anti-linking.c"
				gboolean _tmp129_ = FALSE;
#line 347 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp129_ = found_2;
#line 347 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp127_ = _tmp129_;
#line 2141 "anti-linking.c"
			} else {
#line 347 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp127_ = FALSE;
#line 2145 "anti-linking.c"
			}
#line 347 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			if (_tmp127_) {
#line 2149 "anti-linking.c"
				GMainLoop* _tmp130_ = NULL;
#line 349 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				self->priv->_found_after_final_update = TRUE;
#line 350 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				_tmp130_ = self->priv->_main_loop;
#line 350 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
				g_main_loop_quit (_tmp130_);
#line 2157 "anti-linking.c"
			}
#line 275 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
			_g_object_unref0 (added_unique);
#line 2161 "anti-linking.c"
		}
	}
#line 245 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (removed);
#line 245 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (added);
#line 2168 "anti-linking.c"
}


static void anti_linking_tests_class_init (AntiLinkingTestsClass * klass) {
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	anti_linking_tests_parent_class = g_type_class_peek_parent (klass);
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_type_class_add_private (klass, sizeof (AntiLinkingTestsPrivate));
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	((FolksTestCaseClass *) klass)->set_up = anti_linking_tests_real_set_up;
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	((FolksTestCaseClass *) klass)->tear_down = anti_linking_tests_real_tear_down;
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	G_OBJECT_CLASS (klass)->finalize = anti_linking_tests_finalize;
#line 2183 "anti-linking.c"
}


static void anti_linking_tests_instance_init (AntiLinkingTests * self) {
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	self->priv = ANTI_LINKING_TESTS_GET_PRIVATE (self);
#line 2190 "anti-linking.c"
}


static void anti_linking_tests_finalize (GObject* obj) {
	AntiLinkingTests * self;
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_ANTI_LINKING_TESTS, AntiLinkingTests);
#line 27 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 28 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 25 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	G_OBJECT_CLASS (anti_linking_tests_parent_class)->finalize (obj);
#line 2204 "anti-linking.c"
}


GType anti_linking_tests_get_type (void) {
	static volatile gsize anti_linking_tests_type_id__volatile = 0;
	if (g_once_init_enter (&anti_linking_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AntiLinkingTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) anti_linking_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AntiLinkingTests), 0, (GInstanceInitFunc) anti_linking_tests_instance_init, NULL };
		GType anti_linking_tests_type_id;
		anti_linking_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "AntiLinkingTests", &g_define_type_info, 0);
		g_once_init_leave (&anti_linking_tests_type_id__volatile, anti_linking_tests_type_id);
	}
	return anti_linking_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	AntiLinkingTests* tests = NULL;
	AntiLinkingTests* _tmp0_ = NULL;
#line 358 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_test_init (&args_length1, &args, NULL);
#line 360 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_tmp0_ = anti_linking_tests_new ();
#line 360 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	tests = _tmp0_;
#line 361 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 362 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	g_test_run ();
#line 363 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 365 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	result = 0;
#line 365 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	_g_object_unref0 (tests);
#line 365 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	return result;
#line 2242 "anti-linking.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 356 "/opt/gnome3/source/folks/tests/eds/anti-linking.vala"
	return _vala_main (argv, argc);
#line 2252 "anti-linking.c"
}



